==> Spire.Pdf-9.12.0-py3-none-win_amd64.whl: spire/pdf/PdfFreeTextAnnotation.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfFreeTextAnnotation(PdfAnnotation):
    """
    Represents a free text annotation in a PDF document.
    """

    @dispatch
    def __init__(self, rectangle: RectangleF):
        """
        Initializes a new instance of the PdfFreeTextAnnotation class with the specified rectangle.
        
        Args:
            rectangle (RectangleF): The rectangle of the annotation.
        """
        ptrRec: c_void_p = rectangle.Ptr
        GetDllLibPdf().PdfFreeTextAnnotation_CreatePdfFreeTextAnnotationR.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_CreatePdfFreeTextAnnotationR.restype = c_void_p
        intPtr = GetDllLibPdf().PdfFreeTextAnnotation_CreatePdfFreeTextAnnotationR(ptrRec)
        super(PdfFreeTextAnnotation, self).__init__(intPtr)

    @property
    def LineEndingStyle(self) -> 'PdfLineEndingStyle':
        """
        Gets or sets the line ending style of the annotation.
        
        Returns:
            PdfLineEndingStyle: The line ending style of the annotation.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_get_LineEndingStyle.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_get_LineEndingStyle.restype = c_int
        ret = GetDllLibPdf().PdfFreeTextAnnotation_get_LineEndingStyle(self.Ptr)
        objwrapped = PdfLineEndingStyle(ret)
        return objwrapped

    @LineEndingStyle.setter
    def LineEndingStyle(self, value: 'PdfLineEndingStyle'):
        """
        Sets the line ending style of the annotation.
        
        Args:
            value (PdfLineEndingStyle): The line ending style to set.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_set_LineEndingStyle.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfFreeTextAnnotation_set_LineEndingStyle(self.Ptr, value.value)

    @property
    def AnnotationIntent(self) -> 'PdfAnnotationIntent':
        """
        Gets or sets the intent of the annotation.
        
        Returns:
            PdfAnnotationIntent: The intent of the annotation.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_get_AnnotationIntent.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_get_AnnotationIntent.restype = c_int
        ret = GetDllLibPdf().PdfFreeTextAnnotation_get_AnnotationIntent(self.Ptr)
        objwrapped = PdfAnnotationIntent(ret)
        return objwrapped

    @AnnotationIntent.setter
    def AnnotationIntent(self, value: 'PdfAnnotationIntent'):
        """
        Sets the intent of the annotation.
        
        Args:
            value (PdfAnnotationIntent): The intent to set.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_set_AnnotationIntent.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfFreeTextAnnotation_set_AnnotationIntent(self.Ptr, value.value)

    @property
    def MarkupText(self) -> str:
        """
        Gets or sets the markup text of the annotation.
        
        Returns:
            str: The markup text of the annotation.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_get_MarkupText.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_get_MarkupText.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfFreeTextAnnotation_get_MarkupText(self.Ptr))
        return ret

    @MarkupText.setter
    def MarkupText(self, value: str):
        """
        Sets the markup text of the annotation.
        
        Args:
            value (str): The markup text to set.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_set_MarkupText.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfFreeTextAnnotation_set_MarkupText(self.Ptr, value)

    @property
    def Opacity(self) -> float:
        """
        Gets or sets the opacity of the annotation.
        
        Returns:
            float: The opacity of the annotation.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_get_Opacity.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_get_Opacity.restype = c_float
        ret = GetDllLibPdf().PdfFreeTextAnnotation_get_Opacity(self.Ptr)
        return ret

    @Opacity.setter
    def Opacity(self, value: float):
        """
        Sets the opacity of the annotation.
        
        Args:
            value (float): The opacity to set.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_set_Opacity.argtypes = [c_void_p, c_float]
        GetDllLibPdf().PdfFreeTextAnnotation_set_Opacity(self.Ptr, value)

    @property
    def Font(self) -> 'PdfFontBase':
        """
        Gets or sets the font of the annotation.
        
        Returns:
            PdfFontBase: The font of the annotation.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_get_Font.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_get_Font.restype = c_void_p
        intPtr = GetDllLibPdf().PdfFreeTextAnnotation_get_Font(self.Ptr)
        ret = None if intPtr == None else PdfFontBase(intPtr)
        return ret

    @Font.setter
    def Font(self, value: 'PdfFontBase'):
        """
        Sets the font of the annotation.
        
        Args:
            value (PdfFontBase): The font to set.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_set_Font.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_set_Font(self.Ptr, value.Ptr)

    @property
    def CalloutLines(self) -> List['PointF']:
        """
        Gets or sets the callout lines of the annotation.
        
        Returns:
            List[PointF]: The callout lines of the annotation.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_get_CalloutLines.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_get_CalloutLines.restype = IntPtrArray
        intPtrArray = GetDllLibPdf().PdfFreeTextAnnotation_get_CalloutLines(self.Ptr)
        ret = GetVectorFromArray(intPtrArray, PointF)
        return ret

    @CalloutLines.setter
    def CalloutLines(self, value: List['PointF']):
        """
        Sets the callout lines of the annotation.
        
        Args:
            value (List[PointF]): The callout lines to set.
        """
        vCount = len(value)
        ArrayType = c_void_p * vCount
        vArray = ArrayType()
        for i in range(0, vCount):
            vArray[i] = value[i].Ptr
        GetDllLibPdf().PdfFreeTextAnnotation_set_CalloutLines.argtypes = [c_void_p, ArrayType, c_int]
        GetDllLibPdf().PdfFreeTextAnnotation_set_CalloutLines(self.Ptr, vArray, vCount)

    @property
    def TextMarkupColor(self) -> 'PdfRGBColor':
        """
        Gets or sets the text markup color of the annotation.
        
        Returns:
            PdfRGBColor: The text markup color of the annotation.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_get_TextMarkupColor.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_get_TextMarkupColor.restype = c_void_p
        intPtr = GetDllLibPdf().PdfFreeTextAnnotation_get_TextMarkupColor(self.Ptr)
        ret = None if intPtr == None else PdfRGBColor(intPtr)
        return ret

    @TextMarkupColor.setter
    def TextMarkupColor(self, value: 'PdfRGBColor'):
        """
        Sets the text markup color of the annotation.
        
        Args:
            value (PdfRGBColor): The text markup color to set.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_set_TextMarkupColor.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_set_TextMarkupColor(self.Ptr, value.Ptr)

    @property
    def BorderColor(self) -> 'PdfRGBColor':
        """
        Gets or sets the border color of the annotation.
        
        Returns:
            PdfRGBColor: The border color of the annotation.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_get_BorderColor.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_get_BorderColor.restype = c_void_p
        intPtr = GetDllLibPdf().PdfFreeTextAnnotation_get_BorderColor(self.Ptr)
        ret = None if intPtr == None else PdfRGBColor(intPtr)
        return ret

    @BorderColor.setter
    def BorderColor(self, value: 'PdfRGBColor'):
        """
        Sets the border color of the annotation.
        
        Args:
            value (PdfRGBColor): The border color to set.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_set_BorderColor.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_set_BorderColor(self.Ptr, value.Ptr)

    @property
    def RectangleDifferences(self) -> List[float]:
        """
        Gets or sets the rectangular differences of the annotation.
        
        Returns:
            List[float]: The rectangular differences of the annotation.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_get_RectangleDifferences.argtypes=[c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_get_RectangleDifferences.restype=IntPtrArray
        intPtrArray = GetDllLibPdf().PdfFreeTextAnnotation_get_RectangleDifferences(self.Ptr)
        ret = GetVectorFromArray(intPtrArray, c_float)
        return ret

    @RectangleDifferences.setter
    def RectangleDifferences(self, value:List[float]):
        vCount = len(value)
        ArrayType = c_float * vCount
        vArray = ArrayType()
        for i in range(0, vCount):
            vArray[i] = value[i]
        GetDllLibPdf().PdfFreeTextAnnotation_set_RectangleDifferences.argtypes=[c_void_p, ArrayType, c_int]
        GetDllLibPdf().PdfFreeTextAnnotation_set_RectangleDifferences(self.Ptr, vArray, vCount)

    @property

    def Author(self)->str:
        """

        Gets or sets the user who created the annotation.

        """
        GetDllLibPdf().PdfFreeTextAnnotation_get_Author.argtypes=[c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_get_Author.restype=c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfFreeTextAnnotation_get_Author(self.Ptr))
        return ret


    @Author.setter
    def Author(self, value:str):
        GetDllLibPdf().PdfFreeTextAnnotation_set_Author.argtypes=[c_void_p, c_wchar_p]
        GetDllLibPdf().PdfFreeTextAnnotation_set_Author(self.Ptr, value)

    @property

    def Subject(self)->str:
        """

        Gets or sets the annotation's subject.

        """
        GetDllLibPdf().PdfFreeTextAnnotation_get_Subject.argtypes=[c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_get_Subject.restype=c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfFreeTextAnnotation_get_Subject(self.Ptr))
        return ret


    @Subject.setter
    def Subject(self, value:str):
        GetDllLibPdf().PdfFreeTextAnnotation_set_Subject.argtypes=[c_void_p, c_wchar_p]
        GetDllLibPdf().PdfFreeTextAnnotation_set_Subject(self.Ptr, value)

==> Spire.Pdf-10.12.1-py3-none-win_amd64.whl: spire/pdf/PdfFreeTextAnnotation.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfFreeTextAnnotation(PdfAnnotation):
    """
    Represents a free text annotation in a PDF document.
    """

    @dispatch
    def __init__(self, rectangle: RectangleF):
        """
        Initializes a new instance of the PdfFreeTextAnnotation class with the specified rectangle.
        
        Args:
            rectangle (RectangleF): The rectangle of the annotation.
        """
        ptrRec: c_void_p = rectangle.Ptr
        GetDllLibPdf().PdfFreeTextAnnotation_CreatePdfFreeTextAnnotationR.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_CreatePdfFreeTextAnnotationR.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfFreeTextAnnotation_CreatePdfFreeTextAnnotationR,ptrRec)
        super(PdfFreeTextAnnotation, self).__init__(intPtr)

    @property
    def LineEndingStyle(self) -> 'PdfLineEndingStyle':
        """
        Gets or sets the line ending style of the annotation.
        
        Returns:
            PdfLineEndingStyle: The line ending style of the annotation.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_get_LineEndingStyle.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_get_LineEndingStyle.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfFreeTextAnnotation_get_LineEndingStyle,self.Ptr)
        objwrapped = PdfLineEndingStyle(ret)
        return objwrapped

    @LineEndingStyle.setter
    def LineEndingStyle(self, value: 'PdfLineEndingStyle'):
        """
        Sets the line ending style of the annotation.
        
        Args:
            value (PdfLineEndingStyle): The line ending style to set.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_set_LineEndingStyle.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfFreeTextAnnotation_set_LineEndingStyle,self.Ptr, value.value)

    @property
    def AnnotationIntent(self) -> 'PdfAnnotationIntent':
        """
        Gets or sets the intent of the annotation.
        
        Returns:
            PdfAnnotationIntent: The intent of the annotation.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_get_AnnotationIntent.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_get_AnnotationIntent.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfFreeTextAnnotation_get_AnnotationIntent,self.Ptr)
        objwrapped = PdfAnnotationIntent(ret)
        return objwrapped

    @AnnotationIntent.setter
    def AnnotationIntent(self, value: 'PdfAnnotationIntent'):
        """
        Sets the intent of the annotation.
        
        Args:
            value (PdfAnnotationIntent): The intent to set.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_set_AnnotationIntent.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfFreeTextAnnotation_set_AnnotationIntent,self.Ptr, value.value)

    @property
    def MarkupText(self) -> str:
        """
        Gets or sets the markup text of the annotation.
        
        Returns:
            str: The markup text of the annotation.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_get_MarkupText.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_get_MarkupText.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfFreeTextAnnotation_get_MarkupText,self.Ptr))
        return ret

    @MarkupText.setter
    def MarkupText(self, value: str):
        """
        Sets the markup text of the annotation.
        
        Args:
            value (str): The markup text to set.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_set_MarkupText.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfFreeTextAnnotation_set_MarkupText,self.Ptr, value)

    @property
    def Opacity(self) -> float:
        """
        Gets or sets the opacity of the annotation.
        
        Returns:
            float: The opacity of the annotation.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_get_Opacity.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_get_Opacity.restype = c_float
        ret = CallCFunction(GetDllLibPdf().PdfFreeTextAnnotation_get_Opacity,self.Ptr)
        return ret

    @Opacity.setter
    def Opacity(self, value: float):
        """
        Sets the opacity of the annotation.
        
        Args:
            value (float): The opacity to set.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_set_Opacity.argtypes = [c_void_p, c_float]
        CallCFunction(GetDllLibPdf().PdfFreeTextAnnotation_set_Opacity,self.Ptr, value)

    @property
    def Font(self) -> 'PdfFontBase':
        """
        Gets or sets the font of the annotation.
        
        Returns:
            PdfFontBase: The font of the annotation.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_get_Font.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_get_Font.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfFreeTextAnnotation_get_Font,self.Ptr)
        ret = None if intPtr == None else PdfFontBase(intPtr)
        return ret

    @Font.setter
    def Font(self, value: 'PdfFontBase'):
        """
        Sets the font of the annotation.
        
        Args:
            value (PdfFontBase): The font to set.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_set_Font.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfFreeTextAnnotation_set_Font,self.Ptr, value.Ptr)

    @property
    def CalloutLines(self) -> List['PointF']:
        """
        Gets or sets the callout lines of the annotation.
        
        Returns:
            List[PointF]: The callout lines of the annotation.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_get_CalloutLines.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_get_CalloutLines.restype = IntPtrArray
        intPtrArray = CallCFunction(GetDllLibPdf().PdfFreeTextAnnotation_get_CalloutLines,self.Ptr)
        ret = GetVectorFromArray(intPtrArray, PointF)
        return ret

    @CalloutLines.setter
    def CalloutLines(self, value: List['PointF']):
        """
        Sets the callout lines of the annotation.
        
        Args:
            value (List[PointF]): The callout lines to set.
        """
        vCount = len(value)
        ArrayType = c_void_p * vCount
        vArray = ArrayType()
        for i in range(0, vCount):
            vArray[i] = value[i].Ptr
        GetDllLibPdf().PdfFreeTextAnnotation_set_CalloutLines.argtypes = [c_void_p, ArrayType, c_int]
        CallCFunction(GetDllLibPdf().PdfFreeTextAnnotation_set_CalloutLines,self.Ptr, vArray, vCount)

    @property
    def TextMarkupColor(self) -> 'PdfRGBColor':
        """
        Gets or sets the text markup color of the annotation.
        
        Returns:
            PdfRGBColor: The text markup color of the annotation.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_get_TextMarkupColor.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_get_TextMarkupColor.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfFreeTextAnnotation_get_TextMarkupColor,self.Ptr)
        ret = None if intPtr == None else PdfRGBColor(intPtr)
        return ret

    @TextMarkupColor.setter
    def TextMarkupColor(self, value: 'PdfRGBColor'):
        """
        Sets the text markup color of the annotation.
        
        Args:
            value (PdfRGBColor): The text markup color to set.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_set_TextMarkupColor.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfFreeTextAnnotation_set_TextMarkupColor,self.Ptr, value.Ptr)

    @property
    def BorderColor(self) -> 'PdfRGBColor':
        """
        Gets or sets the border color of the annotation.
        
        Returns:
            PdfRGBColor: The border color of the annotation.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_get_BorderColor.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_get_BorderColor.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfFreeTextAnnotation_get_BorderColor,self.Ptr)
        ret = None if intPtr == None else PdfRGBColor(intPtr)
        return ret

    @BorderColor.setter
    def BorderColor(self, value: 'PdfRGBColor'):
        """
        Sets the border color of the annotation.
        
        Args:
            value (PdfRGBColor): The border color to set.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_set_BorderColor.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfFreeTextAnnotation_set_BorderColor,self.Ptr, value.Ptr)

    @property
    def RectangleDifferences(self) -> List[float]:
        """
        Gets or sets the rectangular differences of the annotation.
        
        Returns:
            List[float]: The rectangular differences of the annotation.
        """
        GetDllLibPdf().PdfFreeTextAnnotation_get_RectangleDifferences.argtypes=[c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_get_RectangleDifferences.restype=IntPtrArray
        intPtrArray = CallCFunction(GetDllLibPdf().PdfFreeTextAnnotation_get_RectangleDifferences,self.Ptr)
        ret = GetVectorFromArray(intPtrArray, c_float)
        return ret

    @RectangleDifferences.setter
    def RectangleDifferences(self, value:List[float]):
        vCount = len(value)
        ArrayType = c_float * vCount
        vArray = ArrayType()
        for i in range(0, vCount):
            vArray[i] = value[i]
        GetDllLibPdf().PdfFreeTextAnnotation_set_RectangleDifferences.argtypes=[c_void_p, ArrayType, c_int]
        CallCFunction(GetDllLibPdf().PdfFreeTextAnnotation_set_RectangleDifferences,self.Ptr, vArray, vCount)

    @property

    def Author(self)->str:
        """

        Gets or sets the user who created the annotation.

        """
        GetDllLibPdf().PdfFreeTextAnnotation_get_Author.argtypes=[c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_get_Author.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfFreeTextAnnotation_get_Author,self.Ptr))
        return ret


    @Author.setter
    def Author(self, value:str):
        GetDllLibPdf().PdfFreeTextAnnotation_set_Author.argtypes=[c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfFreeTextAnnotation_set_Author,self.Ptr, value)

    @property

    def Subject(self)->str:
        """

        Gets or sets the annotation's subject.

        """
        GetDllLibPdf().PdfFreeTextAnnotation_get_Subject.argtypes=[c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotation_get_Subject.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfFreeTextAnnotation_get_Subject,self.Ptr))
        return ret


    @Subject.setter
    def Subject(self, value:str):
        GetDllLibPdf().PdfFreeTextAnnotation_set_Subject.argtypes=[c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfFreeTextAnnotation_set_Subject,self.Ptr, value)
